# Welcome to diebohnen


[![image](https://img.shields.io/pypi/v/diebohnen.svg)](https://pypi.python.org/pypi/diebohnen)


**Python Boilerplate contains all the boilerplate you need to create a Python package.**


-   Free software: MIT License
-   Documentation: <https://phillipslucas.github.io/diebohnen>
    

## Features

-   TODO
